@@ -30,15 +30,23 @@ class Pytifications:
         Use this method to login to the pytifications network,
 
         if you don't have a login yet, go to https://t.me/pytificator_bot and talk to the bot to create your account
+
+        Args:
+            login (:obj:`str`) your login credentials created at the bot
+            password (:obj:`str`) your password created at the bot
+
+        Returns:
+            :obj:`True`if login was successful else :obj:`False`
         """
 
         Pytifications._logged_in = False
 
-        res = requests.post('https://pytifications.herokuapp.com/send_message',{
+        res = requests.post('https://pytifications.herokuapp.com/initialize_script',{
             "username":login,
             "password_hash":hashlib.sha256(password.encode('utf-8')).hexdigest(),
-            "message":""
+            "script_name":sys.argv[0]
         })
+        
         Pytifications._login = login
         Pytifications._password = password
         if res.status_code != 200:
@@ -48,7 +56,7 @@ class Pytifications:
             Pytifications._logged_in = True
             print('success logging in to pytifications!')
 
-        Thread(target=Pytifications._check_if_any_callbacks_to_be_called).start()
+        Thread(target=Pytifications._check_if_any_callbacks_to_be_called,daemon=True).start()
         
         return True
 
@@ -61,6 +69,7 @@ class Pytifications:
                 res = requests.get('https://pytifications.herokuapp.com/get_callbacks',data={
                     "username":Pytifications._login,
                     "password_hash":hashlib.sha256(Pytifications._password.encode('utf-8')).hexdigest(),
+                    "script_name":sys.argv[0]
                 })
             except:
                 pass
@@ -70,6 +79,16 @@ class Pytifications:
                     Pytifications._registered_callbacks[item]()
 
     def send_message(message: str,buttons: List[List[PytificationButton]] = []):
+        """
+        Use this method to send a message to yourself/your group,
+
+        make sure to have called Pytifications.login() before,
+
+
+        Args:
+            message: (:obj:`str`) message to be sent
+            buttons: (:obj:`List[List[PytificationButton]]`) a list of rows each with a list of columns in that row to be used to align the buttons
+        """
         if not Pytifications._check_login():
             return
 
@@ -95,16 +114,40 @@ class Pytifications:
 
         print(f'sent message: "{message}"')
 
-    def edit_last_message(newText:str):
+    def edit_last_message(message:str,buttons: List[List[PytificationButton]] = []):
+        """
+        Use this method to edit the last sent message from this script
+
+        Args:
+            message: (:obj:`str`) message to be sent
+            buttons: (:obj:`List[List[PytificationButton]]`) a list of rows each with a list of columns in that row to be used to align the buttons
+        Returns:
+            :obj:`True` on success and :obj:`False` if no message was sent before
+        """
         if not Pytifications._check_login() or Pytifications._last_message_id == None:
-            return 
+            return False
+
+        requestedButtons = []
+        for row in buttons:
+            rowButtons = []
+            for column in row:
+                Pytifications._registered_callbacks[column.callback.__name__] = column.callback
+                rowButtons.append({
+                    "callback_name":column.callback.__name__,
+                    "text":column.text
+                })
+             
+            requestedButtons.append(rowButtons)
         
         requests.patch('https://pytifications.herokuapp.com/edit_message',data={
             "username":Pytifications._login,
             "password_hash":hashlib.sha256(Pytifications._password.encode('utf-8')).hexdigest(),
-            "message":newText,
-            "message_id":Pytifications._last_message_id
+            "message":message,
+            "message_id":Pytifications._last_message_id,
+            "buttons":requestedButtons
         })
+
+        return True
         
 
     def _check_login():
@@ -115,5 +158,8 @@ class Pytifications:
 
 
     def am_i_logged_in():
+        """
+        Checks if already logged in
+        """
         return Pytifications._logged_in
     
\ No newline at end of file
